<?php 

/*
 * Return a collection of strings to search for within the page content.
 */
function ibl_get_possible_page_links($request){
    $possible_page_references = array('href="'.$request.'"', 
          'href="'.get_site_url().$request.'"', 
          'href="'.get_site_url().rtrim($request, '/').'"', 
          'href="'.rtrim($request, '/').'"'
        );

    return $possible_page_references;
}

/*
 * Retrieve all the anchor links within the content to the current page for a url.
 */
function ibl_get_content_anchor_links($page_relative_urls, $content){
    
    foreach($page_relative_urls as $url):
        $search_position = 0;
        $link_positions = array();
        
        while (($search_position = strpos($content, $url, $search_position))!== false):
            $link_positions[] = $search_position;
            $search_position = $search_position + strlen($url);
        endwhile;

        foreach($link_positions as $link_position):
            $link_start = strpos($content, '>', $link_position) + 1;
            $link_end = strpos($content, '</a>', $link_start);
            $link_length = $link_end - $link_start;
            $link_text = strip_tags(substr($content, $link_start, $link_length));
                
            if($link_position): ?>
                <div class="anchor-text-item"><?php echo $link_text; ?></div>
            <?php endif;
        endforeach;
    endforeach;
}

/*
 * Retrieve all the anchor links within the acf fields to the current page for a url.
 */
function ibl_get_acf_anchor_links($page_relative_urls, $acf_content){
    
    foreach($page_relative_urls as $url):
        $search_position = 0;
        $link_positions = array();
        
        while (($search_position = strpos($acf_content, $url, $search_position))!== false):
            $link_positions[] = $search_position;
            $search_position = $search_position + strlen($url);
        endwhile;
        
        foreach($link_positions as $link_position):
            $link_start = strpos($acf_content, '>', $link_position) + 1;
            $link_end = strpos($acf_content, '</', $link_start);
            $link_length = $link_end - $link_start;
            $link_text = substr($acf_content, $link_start, $link_length);
                
            if($link_position): ?>
                <div class="anchor-text-item"><?php echo $link_text; ?></div>
            <?php endif;
        endforeach;
    endforeach;
}

/*
 * Get the meta bar
 */
function ibl_meta_bar($search, $post_count){ ?>
	<div class="meta">
	<div class="left-side">
		<div><span class="key">Inputted page keyphrase:</span> <span class="value"><?php echo $search; ?></span></div>
		<div><span class="key">Pages found with potential linking opportunities: </span> <span class="value"><?php echo $post_count; ?></span></div>
	</div>
	<div class="right-side">
		<div class="update-keyphrase">Change page keyphrase</div>
	</div>
</div>
<?php }

/*
 * Get pages acf content
 */
function ibl_get_acf_content(){
    
    if(class_exists('ACF')):

        $valid_acf_types = array(
            'text',
            'textarea',
            'wysiwyg',
            'link',
            'flexible_content',
            'repeater',
            'block'
        );

        $acf_content = array();
        foreach(get_field_objects() as $acf_field):
            if(in_array($acf_field['type'], $valid_acf_types)):

                if($acf_field['type'] == 'block'):

                    var_dump($acf_field);

                elseif($acf_field['type'] == 'repeater'):

                    /*Repeaters*/
                    $acf_content = ibl_sanitize_repeater_field($acf_field, $acf_content);

                elseif($acf_field['type'] == 'flexible_content'):
                    
                    /*Flexible content fields*/
                    foreach($acf_field['value'] as $flex_field):
                        foreach($flex_field as $flex_option => $flex_value):
                            if($flex_option != 'acf_fc_layout'):
                                if(is_array($flex_value)):
                                    $acf_content[] = ibl_convert_multi_array($flex_value);
                                else:
                                    $acf_content[] = $flex_value;
                                endif;
                            endif;
                        endforeach;
                    endforeach;

                else:
                    $acf_content[] = $acf_field['value'];
                endif;
            endif;
        endforeach;
        $content = implode(' ', $acf_content);
        return $content;
    endif;
    
}

function ibl_sanitize_repeater_field($acf_field, $acf_content){
    while(have_rows($acf_field['name'])): the_row();
        foreach($acf_field['value'] as $acf_sub_field):
            foreach($acf_sub_field as $key => $value):
                
                /* Add href if is a link field */
                if(! preg_match('/\s/', $value)):
                    $value = '<a href="'.$value.'">**acf dynamically populated anchor**</a>';
                endif;
                
                $acf_content[] = $value;
            endforeach;
        endforeach;
    endwhile;

    return $acf_content;
}

function ibl_convert_multi_array($array) {
    $out = implode("&",array_map(function($a) {return implode("~",$a);},$array));
    return $out;
  }

function ibl_is_gutenberg($content){
    return false !== strpos( $content, '<!-- wp:' );
}

function ibl_get_block_content($content){
    if(ibl_is_gutenberg($content)):
        $blocks = parse_blocks($content);
        $content = '';
        foreach($blocks as $block){
            $content .= render_block($block);
        }
    endif;
    return $content;
}